@@ -1,7 +1,7 @@
 """
 Type annotations for appflow service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/literals/)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/literals.html)
 
 Usage::
 
@@ -53,10 +53,7 @@ __all__ = (
     "VeevaConnectorOperatorType",
     "WriteOperationTypeType",
     "ZendeskConnectorOperatorType",
-    "AppflowServiceName",
     "ServiceName",
-    "ResourceServiceName",
-    "RegionName",
 )
 
 
@@ -397,7 +394,6 @@ ZendeskConnectorOperatorType = Literal[
     "VALIDATE_NON_ZERO",
     "VALIDATE_NUMERIC",
 ]
-AppflowServiceName = Literal["appflow"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -686,33 +682,3 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
-ResourceServiceName = Literal[
-    "cloudformation",
-    "cloudwatch",
-    "dynamodb",
-    "ec2",
-    "glacier",
-    "iam",
-    "opsworks",
-    "s3",
-    "sns",
-    "sqs",
-]
-RegionName = Literal[
-    "af-south-1",
-    "ap-northeast-1",
-    "ap-northeast-2",
-    "ap-south-1",
-    "ap-southeast-1",
-    "ap-southeast-2",
-    "ca-central-1",
-    "eu-central-1",
-    "eu-west-1",
-    "eu-west-2",
-    "eu-west-3",
-    "sa-east-1",
-    "us-east-1",
-    "us-east-2",
-    "us-west-1",
-    "us-west-2",
-]
